import { Fragment, jsx } from "react/jsx-runtime";
import { Suspense, memo } from "react";
import { matchRoutes, useLocation } from "react-router-dom";
import siteData from "virtual-site-data";
import { normalizeRoutePath } from "./utils";
import { useViewTransition } from "./hooks";
const { routes } = process.env.__SSR__ ? require("virtual-routes-ssr") : require("virtual-routes");
function TransitionContentImpl(props) {
  let element = props.el;
  if (siteData?.themeConfig?.enableContentAnimation) {
    element = useViewTransition(props.el);
  }
  return element;
}
const TransitionContent = memo(
  TransitionContentImpl,
  (prevProps, nextProps) => prevProps.el === nextProps.el
);
const Content = ({ fallback = /* @__PURE__ */ jsx(Fragment, {}) }) => {
  const { pathname } = useLocation();
  const matched = matchRoutes(routes, normalizeRoutePath(pathname));
  if (!matched) {
    return /* @__PURE__ */ jsx("div", {});
  }
  const routesElement = matched[0].route.element;
  if (!process.env.__IS_REACT_18__ && process.env.__SSR__) {
    return routesElement;
  }
  return /* @__PURE__ */ jsx(Suspense, { fallback, children: /* @__PURE__ */ jsx(TransitionContent, { el: routesElement }) });
};
export {
  Content
};
